FiftyCursorStyle enum

Cursor style options for FiftyTextField.

  • line: Standard thin line cursor
  • block: Block cursor (terminal style)
  • underscore: Underscore cursor
Inheritance
Available extensions

Values

line → const FiftyCursorStyle

Standard thin line cursor.

block → const FiftyCursorStyle

Block cursor (terminal style).

underscore → const FiftyCursorStyle

Underscore cursor.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FiftyCursorStyle>
A constant List of the values in this enum, in order of their declaration.